# MoaT-Box

% start synopsis

This module manages boxes, i.e. things you can put other things into.

"Box" is meant to be inclusive. A room is a box. So is a cupboard, or a row
of books. Some boxes can be nested, with locations. Some boxes can be moved
(e.g. a bookcase or a drawer), some can't (the compartments within a drawer)

Boxes are typed. You can put a cupboard into a room but not vice versa.

Boxes are labelled. A box can have an arbitrary number of labels, though
most of the time it'll have one, or at most two: one with a barcode and a
box number, and one with a text that describes the content – or at least
reminds the owner of it.

% end synopsis
